/*
   CheckList
   Copyright (C) 1999 Jarek Woloszyn (yossa@pld.org.pl)

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
 */

#ifndef H_NEWT_CHECKLIST
#define H_NEWT_CHECKLIST

#ifdef __cplusplus
extern "C" {
#endif

#include <stdarg.h>
#include <newt.h>

#define NEWT_CHECKLIST_UNSELECTABLE -1
#define NEWT_CHECKLIST_SELECT_NOT 0
#define NEWT_CHECKLIST_SELECT_RED 1
#define NEWT_CHECKLIST_SELECT_BLUE 2
#define NEWT_CHECKLIST_SELECT_GREEN 3
    
    enum newtChecklistStatus {
	NEWT_CHECKLIST_MOVE, NEWT_CHECKLIST_ENTER,
	NEWT_CHECKLIST_SELECT
    };


    newtComponent newtChecklist(int left, int top, int height, int flags);
    void *newtChecklistGetCurrent(newtComponent co);
    char newtChecklistGetCurrentValue(newtComponent co);
    char newtChecklistGetCurrentValueByKey(newtComponent co, void *key);
    void newtChecklistSetValue(newtComponent co, int num, int val);
    void newtChecklistSetValueByKey(newtComponent co, void *data, int val);

    void newtChecklistSetMCType(newtComponent co, int val);
    enum newtChecklistStatus newtChecklistGetStatus(newtComponent co);
    void newtChecklistSetStatus(newtComponent co, enum newtChecklistStatus stat);


    void newtChecklistSetCurrent(newtComponent co, int num);
    void newtChecklistSetCurrentByKey(newtComponent co, void *key);

    void newtChecklistSetEntry(newtComponent co, int num, const char *text);
    void newtChecklistSetWidth(newtComponent co, int width);
    void newtChecklistSetData(newtComponent co, int num, void *data);
    int newtChecklistAppendEntry(newtComponent co, const char *text,
				 const void *data);
    int newtChecklistAppendCheckbox(newtComponent co, const char *text, int value,
				    const void *data);
    void newtChecklistSetCheckboxPtr(newtComponent co, int index, char *ptr);

/* Send the key to insert after, or NULL to insert at the top */
    int newtChecklistInsertEntry(newtComponent co, const char *text, const void *data, void *key);
    int newtChecklistInsertCheckbox(newtComponent co, const char *text, int value,
				    const void *data, void *key);
    int newtChecklistDeleteEntry(newtComponent co, void *data);
    void newtChecklistClear(newtComponent co);	/* removes all entries from listbox */
    void newtChecklistGetEntry(newtComponent co, int num, char **text, void **data);
/* Returns an array of data pointers from items, last element is NULL */
    void **newtChecklistGetSelection(newtComponent co, int *numitems);
    void newtChecklistClearSelection(newtComponent co);
    void newtChecklistSelectItem(newtComponent co, const void *key,
				 enum newtFlagsSense sense);

#ifdef __cplusplus
}				/* End of extern "C" { */

#endif
#endif				/* H_NEWT_CHECKLIST */
